import 'package:collection/collection.dart';
import 'package:designflow_widgets/designflow_widgets.dart';
import 'package:flutter/material.dart';

class OpenWMaterialAppBar extends StatelessWidget {
  const OpenWMaterialAppBar({
    super.key,
    required this.nodeState,
    required this.textStyle,
    required this.title,
    required this.fill,
    required this.children,
  });

  final WidgetState nodeState;
  final FGeneralTypeInput title;
  final FTextStyle textStyle;
  final FFill fill;
  final List<CNode> children;

  @override
  Widget build(BuildContext context) {
    return BlocBuildersForNodes(
      node: nodeState.node,
      builder: (context, state, stylesState, themeMode) {
        final backgroundColor = fill.getColor(
          context,
          nodeState.loop,
        );

        final foregroundColor = textStyle.fill.getColor(
          context,
          nodeState.loop,
        );

        return AppBar(
          backgroundColor: backgroundColor,
          leading: children.firstOrNull == null
              ? Navigator.canPop(context)
                  ? IconButton(
                      onPressed: () {
                        Navigator.of(context).pop();
                      },
                      icon: Icon(
                        Icons.arrow_back,
                        color: foregroundColor,
                      ),
                    )
                  : null
              : ChildBuilder(
                  context: context,
                  state: nodeState,
                  child: children.firstOrNull,
                ).build(),
          title: TextBuilder(
            nodeState: nodeState,
            textStyle: textStyle,
            value: title,
          ),
          actions: <Widget?>[
            for (final child in children.skip(1))
              ChildBuilder(
                context: context,
                state: nodeState,
                child: child,
              ).build(),
          ].whereNotNull().toList(),
        );
      },
    );
  }
}
